@@ -47,7 +47,6 @@
 #include <kxmlguifactory.h>
 #include <kglobal.h>
 #include <kactioncollection.h>
-#include <ktoggleaction.h>
 #include <KProcess>
 #include <KTabWidget>
 
@@ -922,8 +921,8 @@ void KMixWindow::plugged(const char* driverName, const QString& udi, QString& de
 	{
 		kDebug()
 		<< "Plugged: dev=" << dev << "\n";
-		MixerToolBox::instance()->possiblyAddMixer(mixer);
-		recreateGUI(true, mixer->id(), true, false);
+		if (MixerToolBox::instance()->possiblyAddMixer(mixer))
+			recreateGUI(true, mixer->id(), true, false);
 	}
 }
 
